package org.example;

import com.fasterxml.jackson.databind.JsonNode;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

@Service
public class GameInfoMapper
{
    public GameInfoResponse mapGameInfoJson(JsonNode node)
    {
        GameInfoResponse response = new GameInfoResponse();
        response.setName(node.get("name").toString().replaceAll("\"", ""));
        response.setPage_image(node.get("page_image").toString().replaceAll("\"", ""));
        response.setSmall_logo(node.get("small_logo").toString().replaceAll("\"", ""));

        if (node.get("apps").isArray())
        {
            ArrayList<GameInfoResponse.AppClass> apps = new ArrayList<>();
            for (JsonNode jsonNode : node.get("apps"))
            {
                apps.add(new GameInfoResponse.AppClass(jsonNode.get("id").asInt(), jsonNode.get("name").toString().replaceAll("\"", "")));
            }
            response.setApps(apps);
        }
        GameInfoResponse.Price price = null;
        if (node.get("price") != null)
        {
             price = new GameInfoResponse.Price(node.get("price").get("currency").toString().replaceAll("\"", ""), node.get("price").get("initial").asInt(), node.get("price").get("final").asInt(), node.get("price").get("discount_percent").asInt(), node.get("price").get("individual").asInt());
        }
        response.setPrice(price);

        GameInfoResponse.Platforms platforms = new GameInfoResponse.Platforms(node.get("platforms").get("windows").asBoolean(), node.get("platforms").get("mac").asBoolean(), node.get("platforms").get("linux").asBoolean());
        response.setPlatforms(platforms);

        GameInfoResponse.Controller controller = new GameInfoResponse.Controller(node.get("controller").get("full_gamepad").asBoolean());
        response.setController(controller);

        GameInfoResponse.ReleaseDate releaseDate = null;
        try
        {
            String jsonDate = node.get("release_date").get("date").toString().replaceAll("\"", "");
            Date formattedDate = null;
            if (!jsonDate.isEmpty())
            {
                formattedDate = new SimpleDateFormat("dd MMM, yyyy", Locale.ENGLISH).parse(jsonDate);
            }
            releaseDate = new GameInfoResponse.ReleaseDate(node.get("release_date").get("coming_soon").asBoolean(), formattedDate);
        }
        catch (ParseException e)
        {
            throw new RuntimeException(e);
        }
        response.setRelease_date(releaseDate);

        return response;
    }
}
