package org.example;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import redis.clients.jedis.HostAndPort;
import redis.clients.jedis.JedisPooled;

import java.io.IOException;
import java.security.GeneralSecurityException;

@Service
public class LoadGameService
{
    @Autowired
    private RedisService redisService;

    @Autowired
    private GameInfoMapper mapper;


    public void loadGamesbySingleThread() throws InterruptedException
    {
        try (JedisPooled jedis = new JedisPooled(new HostAndPort(SteamConstants.REDIS_HOST, 6380), redisService.prepareRedisConfig()))
        {

            JsonNode json;
            int i = 0;
            while (i < 150000)
            {
                try
                {
                    json = redisService.loadGameJson(String.format(SteamConstants.GAME_DETAILS_API_TEMPLATE, i, "KZ"));
                }
                catch (IOException e)
                {
                    //TODO: add pushing logs to kibana or etc..
                    e.printStackTrace();
                    if (e.getMessage().equals("429"))
                    {
                        Thread.sleep(240000);
                        continue;
                    }
                    i++;
                    continue;

                }
                if (json.get(Integer.toString(i)).get("success").asBoolean())
                {
                    GameInfoResponse infoResponse = mapper.mapGameInfoJson(json.get(Integer.toString(i)).get("data"));
                    jedis.set(infoResponse.getName(), new ObjectMapper().writeValueAsString(infoResponse));
                    System.out.println("Current id = " + i);
                    System.out.println(json.toPrettyString());
                    GameInfoResponse newResponse = new ObjectMapper().readValue(jedis.get(infoResponse.getName()), GameInfoResponse.class);
                    System.out.println("Value loaded from Redis = " + jedis.get(json.get(Integer.toString(i)).get("data").get("name").toString()));
                }
                else
                {
                    System.out.println("Game with id = " + i + " does not exist in Steam");
                }
                i++;
            }

        }
        catch (GeneralSecurityException | IOException ex)
        {
            //TODO: add pushing logs to kibana or etc..
            ex.printStackTrace();
        }
    }
}
